@@ -72,14 +72,32 @@ namespace Banshee.Sources
     }
 
     public delegate bool TrackEqualHandler (DatabaseTrackInfo a, TrackInfo b);
+    public delegate object TrackExternalObjectHandler (DatabaseTrackInfo a);
+    public delegate string TrackArtworkIdHandler (DatabaseTrackInfo a);
 
     public abstract class PrimarySource : DatabaseSource, IDisposable
     {
+        #region Functions that let us override some behavior of our DatabaseTrackInfos
+        
         private TrackEqualHandler track_equal_handler;
         public TrackEqualHandler TrackEqualHandler {
             get { return track_equal_handler; }
             protected set { track_equal_handler = value; }
         }
+
+        private TrackExternalObjectHandler track_external_object_handler;
+        public TrackExternalObjectHandler TrackExternalObjectHandler {
+            get { return track_external_object_handler; }
+            protected set { track_external_object_handler = value; }
+        }
+
+        private TrackArtworkIdHandler track_artwork_id_handler;
+        public TrackArtworkIdHandler TrackArtworkIdHandler {
+            get { return track_artwork_id_handler; }
+            protected set { track_artwork_id_handler = value; }
+        }
+
+        #endregion
     
         protected ErrorSource error_source;
         protected bool error_source_visible = false;
@@ -243,12 +261,12 @@ namespace Banshee.Sources
             primary_sources[DbId] = this;
             
             // Load our playlists and smart playlists
-            foreach (PlaylistSource pl in PlaylistSource.LoadAll (DbId)) {
+            foreach (PlaylistSource pl in PlaylistSource.LoadAll (this)) {
                 AddChildSource (pl);
             }
 
             int sp_count = 0;
-            foreach (SmartPlaylistSource pl in SmartPlaylistSource.LoadAll (DbId)) {
+            foreach (SmartPlaylistSource pl in SmartPlaylistSource.LoadAll (this)) {
                 AddChildSource (pl);
                 sp_count++;
             }
@@ -274,7 +292,7 @@ namespace Banshee.Sources
             }
 
             expanded_schema = new SchemaEntry<bool> (
-                String.Format ("sources.{0}", ConfigurationId), "expanded", true, "Is source expanded", "Is source expanded"
+                String.Format ("sources.{0}", ParentConfigurationId), "expanded", true, "Is source expanded", "Is source expanded"
             );
         }
 
@@ -531,8 +549,9 @@ namespace Banshee.Sources
         
         public override bool AddAllTracks (Source source)
         {
-            if (!AcceptsInputFromSource (source) || source.Count == 0)
+            if (!AcceptsInputFromSource (source) || source.Count == 0) {
                 return false;
+            }
             
             DatabaseTrackListModel model = (source as ITrackModelSource).TrackModel as DatabaseTrackListModel;
             CachedList<DatabaseTrackInfo> cached_list = CachedList<DatabaseTrackInfo>.CreateFromModel (model);
@@ -602,19 +621,20 @@ namespace Banshee.Sources
                     finished = true;
                     add_track_job = null;
                 } else {
-                    add_track_job.Status = String.Empty;
                     if (add_track_job.Completed % 10 == 0)
                         notify = true;
                 }
             }
 
+            if (finished) {
+                is_adding = false;
+            }
+
             if (notify || finished) {
-                Banshee.Base.ThreadAssist.ProxyToMain (delegate {
-                    OnTracksAdded ();
-    
-                if (finished)
-                    OnUserNotifyUpdated ();
-                });
+                OnTracksAdded ();
+                if (finished) {
+                    Banshee.Base.ThreadAssist.ProxyToMain (OnUserNotifyUpdated);
+                }
             }
         }
 
