@@ -205,7 +205,7 @@ namespace Banshee.Gui.TrackEditor
                     }
                     page.Changed += OnPageChanged;
                 } catch (Exception e) {
-                    Hyena.Log.Exception ("Invalid NotebookPage extension node. Should implement ITrackEditorPage.", e);
+                    Hyena.Log.Exception ("Failed to initialize NotebookPage extension node. Ensure it implements ITrackEditorPage.", e);
                 }
             }
             
@@ -326,7 +326,9 @@ namespace Banshee.Gui.TrackEditor
         private void InvokeFieldSync ()
         {
             ForeachWidget<SyncButton> (delegate (SyncButton button) {
-                button.Click ();
+                if (button.Sensitive) {
+                    button.Click ();
+                }
             });
         }
         
@@ -389,7 +391,7 @@ namespace Banshee.Gui.TrackEditor
             }
             
             ArtworkManager artwork = ServiceManager.Get<ArtworkManager> ();
-            Gdk.Pixbuf cover_art = artwork.LookupScale (current_track.ArtworkId, 64);
+            Gdk.Pixbuf cover_art = artwork.LookupScalePixbuf (current_track.ArtworkId, 64);
             header_image.Pixbuf = cover_art;
             if (cover_art == null) {
                 header_image.IconName = "media-optical";
@@ -549,7 +551,10 @@ namespace Banshee.Gui.TrackEditor
 
                 // Finally, notify the affected primary sources
                 foreach (int id in primary_sources) {
-                    PrimarySource.GetById (id).NotifyTracksChanged ();
+                    PrimarySource psrc = PrimarySource.GetById (id);
+                    if (psrc != null) {
+                        psrc.NotifyTracksChanged ();
+                    }
                 }
             } finally {
                 DatabaseTrackInfo.NotifySaved = true;
