@@ -428,6 +428,11 @@ namespace Banshee.Dap.MassStorage
                 Directory.Create (System.IO.Path.GetDirectoryName (new_uri.LocalPath));
                 File.Copy (fromUri, new_uri, false);
 
+                // TODO If write-to-file is NOT on, then write the metadata in db to the file on the DAP
+                // to ensure that when we load it next time, it's data will match what's in the database
+                // and the MetadataHash will actually match.  This isn't necessary on iPods or MTP since
+                // on them we store our db's metadata in their dbs.
+
                 DatabaseTrackInfo copied_track = new DatabaseTrackInfo (track);
                 copied_track.PrimarySource = this;
                 copied_track.Uri = new_uri;
@@ -453,10 +458,10 @@ namespace Banshee.Dap.MassStorage
                             SafeUri local_cover_uri = new SafeUri (Banshee.Base.CoverArtSpec.GetPath (coverart_id));
                             Banshee.IO.File.Copy (local_cover_uri, cover_uri, false);
                         } else {
-                            pic = artwork_manager.Lookup (coverart_id);
+                            pic = artwork_manager.LookupPixbuf (coverart_id);
                         }
                     } else {
-                        pic = artwork_manager.LookupScale (coverart_id, CoverArtSize);
+                        pic = artwork_manager.LookupScalePixbuf (coverart_id, CoverArtSize);
                     }
 
                     if (pic != null) {
@@ -468,7 +473,7 @@ namespace Banshee.Dap.MassStorage
                         } catch (GLib.GException){
                             Log.DebugFormat ("Could convert cover art to {0}, unsupported filetype?", CoverArtFileType);
                         } finally {
-                            pic.Dispose ();
+                            Banshee.Collection.Gui.ArtworkManager.DisposePixbuf (pic);
                         }
                     }
                 }
