@@ -41,21 +41,17 @@ namespace Banshee.NowPlaying
     public class NowPlayingInterface : VBox, ISourceContents
     {   
         private NowPlayingSource source;
-        private VideoDisplay video_display;
         private Hyena.Widgets.RoundedFrame frame;
         private Gtk.Window video_window;
         private FullscreenAdapter fullscreen_adapter;
         private ScreensaverManager screensaver;
-
-        public VideoDisplay VideoDisplay {
-            get { return video_display; }
-        }
+        private NowPlayingContents contents;
         
         public NowPlayingInterface ()
         {
             GtkElementsService service = ServiceManager.Get<GtkElementsService> ();
             
-            video_display = new XOverlayVideoDisplay ();
+            contents = new NowPlayingContents ();
             
             // This is my really sweet hack - it's where the video widget
             // is sent when the source is not active. This keeps the video
@@ -65,7 +61,7 @@ namespace Banshee.NowPlaying
             video_window = new FullscreenWindow (service.PrimaryWindow);
             video_window.Hidden += OnFullscreenWindowHidden;
             video_window.Realize ();
-            video_window.Add (video_display);
+            video_window.Add (contents);
             
             frame = new Hyena.Widgets.RoundedFrame ();
             frame.SetFillColor (new Cairo.Color (0, 0, 0));
@@ -84,20 +80,19 @@ namespace Banshee.NowPlaying
             screensaver.Dispose ();
         }
 
-        
         private void MoveVideoExternal (bool hidden)
         {
-            if (video_display.Parent != video_window) {
-                video_display.Visible = !hidden;
-                video_display.Reparent (video_window);
+            if (contents.Parent != video_window) {
+                contents.Visible = !hidden;
+                contents.Reparent (video_window);
             }
         }
         
         private void MoveVideoInternal ()
         {
-            if (video_display.Parent != frame) {
-                video_display.Reparent (frame);
-                video_display.Show ();
+            if (contents.Parent != frame) {
+                contents.Reparent (frame);
+                contents.Show ();
             }
         }
         
@@ -162,7 +157,7 @@ namespace Banshee.NowPlaying
         {
             if (fullscreen) {
                 MoveVideoExternal (true);
-                video_window.ShowAll ();
+                video_window.Show ();
                 fullscreen_adapter.Fullscreen (video_window, true);
                 screensaver.Inhibit ();
             } else {
