@@ -107,12 +107,22 @@ namespace Banshee.PlayQueue
 #region IPlayQueue, IDBusExportable
 
         public void EnqueueUri (string uri)
+        {
+            EnqueueUri (uri, false);
+        }
+
+        public void EnqueueUri (string uri, bool prepend)
         {
             int track_id = LibrarySource.GetTrackIdForUri (uri);
             if (track_id > 0) {
+                if (prepend) {
+                    ServiceManager.DbConnection.Execute ("UPDATE CorePlaylistEntries SET ViewOrder = ViewOrder + 1 WHERE PlaylistID = ?", DbId);
+                }
+
                 HyenaSqliteCommand insert_command = new HyenaSqliteCommand (String.Format (
-                    @"INSERT INTO CorePlaylistEntries (PlaylistID, TrackID) VALUES ({0}, ?)", DbId));
+                    @"INSERT INTO CorePlaylistEntries (PlaylistID, TrackID, ViewOrder) VALUES ({0}, ?, {1})", DbId, prepend ? 0 : MaxViewOrder));
                 ServiceManager.DbConnection.Execute (insert_command, track_id);
+
                 Reload ();
                 NotifyUser ();
             }
@@ -189,7 +199,7 @@ namespace Banshee.PlayQueue
         private void OnPlayerEvent (PlayerEventArgs args)
         {
             if (args.Event == PlayerEvent.EndOfStream) {
-                if (RemovePlayingTrack ()) {
+                if (RemovePlayingTrack () && Count == 0) {
                     if (was_playing) {
                         ServiceManager.PlaybackController.PriorTrack = prior_playback_track;
                     } else {
