@@ -55,7 +55,8 @@ namespace Banshee.Podcasting
     public partial class PodcastService : IExtensionService, IDisposable, IDelayedInitializeService
     {  
         private readonly string tmp_download_path;
-        private string tmp_enclosure_path; 
+        private string tmp_enclosure_path;
+        private uint refresh_timeout_id = 0;
             
         private bool disposed;
         
@@ -81,14 +82,6 @@ namespace Banshee.Podcasting
             download_manager_iface.Initialize ();    
     
             feeds_manager = new FeedsManager (ServiceManager.DbConnection, download_manager, Path.Combine (Banshee.Base.Paths.CachedLibraryLocation, "Podcasts"));
-            
-            feeds_manager.FeedManager.ItemAdded += OnItemAdded;
-            feeds_manager.FeedManager.ItemChanged += OnItemChanged;
-            feeds_manager.FeedManager.ItemRemoved += OnItemRemoved;
-            feeds_manager.FeedManager.FeedsChanged += OnFeedsChanged;
-
-            ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.StateChange);
-            ServiceManager.Get<DBusCommandService> ().ArgumentPushed += OnCommandLineArgument;
 
             InitializeInterface ();
         }
@@ -155,11 +148,11 @@ namespace Banshee.Podcasting
                         );
 
                         if (track_id > 0) {
-                            PodcastTrackInfo track = PodcastTrackInfo.Provider.FetchSingle (track_id);
-                            track.Item = enclosure.Item;
-                            track.PrimarySourceId = source.DbId;
-                            track.SyncWithFeedItem ();
-                            track.Save (false);
+                            PodcastTrackInfo pi = new PodcastTrackInfo (DatabaseTrackInfo.Provider.FetchSingle (track_id));
+                            pi.Item = enclosure.Item;
+                            pi.Track.PrimarySourceId = source.DbId;
+                            pi.SyncWithFeedItem ();
+                            pi.Track.Save (false);
                             moved++;
                         }
                     }
@@ -189,6 +182,33 @@ namespace Banshee.Podcasting
 
                 DatabaseConfigurationClient.Client.Set<int> ("Podcast", "Version", 3);
             }
+
+            // Intentionally skpping 4 here because this needs to get run again for anybody who ran it
+            // before it was fixed, but only once if you never ran it
+            if (DatabaseConfigurationClient.Client.Get<int> ("Podcast", "Version", 0) < 5) {
+                ReplaceNewlines ("CoreTracks", "Title");
+                ReplaceNewlines ("CoreTracks", "TitleLowered");
+                ReplaceNewlines ("PodcastItems", "Title");
+                ReplaceNewlines ("PodcastItems", "Description");
+                DatabaseConfigurationClient.Client.Set<int> ("Podcast", "Version", 5);
+            }
+
+            // Initialize the new StrippedDescription field
+            if (DatabaseConfigurationClient.Client.Get<int> ("Podcast", "Version", 0) < 6) {
+                foreach (FeedItem item in FeedItem.Provider.FetchAll ()) {
+                    item.UpdateStrippedDescription ();
+                    item.Save ();
+                }
+                DatabaseConfigurationClient.Client.Set<int> ("Podcast", "Version", 6);
+            }
+        }
+
+        private void ReplaceNewlines (string table, string column)
+        {
+            string cmd = String.Format ("UPDATE {0} SET {1}=replace({1}, ?, ?)", table, column);
+            ServiceManager.DbConnection.Execute (cmd, "\r\n", String.Empty);
+            ServiceManager.DbConnection.Execute (cmd, "\n", String.Empty);
+            ServiceManager.DbConnection.Execute (cmd, "\r", String.Empty);
         }
         
         public void Initialize ()
@@ -199,16 +219,19 @@ namespace Banshee.Podcasting
         {
             // Migrate data from 0.13.2 podcast tables, if they exist
             MigrateLegacyIfNeeded ();
-            
-            Banshee.Kernel.Scheduler.Schedule (new Banshee.Kernel.DelegateJob (delegate {
-                DateTime now = DateTime.Now;
-                foreach (Feed feed in Feed.Provider.FetchAll ()) {
-                    if ((now - feed.LastDownloadTime).TotalHours > 1) {
-                        feed.Update ();
-                        RefreshArtworkFor (feed);
-                    }
-                }
-            }));
+
+            feeds_manager.FeedManager.ItemAdded += OnItemAdded;
+            feeds_manager.FeedManager.ItemChanged += OnItemChanged;
+            feeds_manager.FeedManager.ItemRemoved += OnItemRemoved;
+            feeds_manager.FeedManager.FeedsChanged += OnFeedsChanged;
+
+            ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.StateChange);
+            ServiceManager.Get<DBusCommandService> ().ArgumentPushed += OnCommandLineArgument;
+
+            RefreshFeeds ();
+
+            // Every 10 minutes try to refresh again
+            refresh_timeout_id = Application.RunTimeout (1000 * 60 * 10, RefreshFeeds);
         }
         
         bool disposing;
@@ -221,6 +244,9 @@ namespace Banshee.Podcasting
                     disposing = true;               
                 }
             }
+
+            Application.IdleTimeoutRemove (refresh_timeout_id);
+            refresh_timeout_id = 0;
             
             ServiceManager.PlayerEngine.DisconnectEvent (OnPlayerEvent);
             ServiceManager.Get<DBusCommandService> ().ArgumentPushed -= OnCommandLineArgument;
@@ -247,6 +273,21 @@ namespace Banshee.Podcasting
                 disposed = true;
             }
         }
+
+        private bool RefreshFeeds ()
+        {
+            Hyena.Log.Debug ("Refreshing any podcasts that haven't been updated in over an hour");
+            Banshee.Kernel.Scheduler.Schedule (new Banshee.Kernel.DelegateJob (delegate {
+                DateTime now = DateTime.Now;
+                foreach (Feed feed in Feed.Provider.FetchAll ()) {
+                    if ((now - feed.LastDownloadTime).TotalHours > 1) {
+                        feed.Update ();
+                        RefreshArtworkFor (feed);
+                    }
+                }
+            }));
+            return true;
+        }
         
         private void OnCommandLineArgument (string uri, object value, bool isFile)
         {
@@ -281,12 +322,19 @@ namespace Banshee.Podcasting
                 Banshee.Kernel.Scheduler.Schedule (new PodcastImageFetchJob (feed), Banshee.Kernel.JobPriority.BelowNormal);
             }
         }
+
+        private DatabaseTrackInfo GetTrackByItemId (long item_id)
+        {
+            return DatabaseTrackInfo.Provider.FetchFirstMatching ("PrimarySourceID = ? AND ExternalID = ?", source.DbId, item_id);
+        }
         
         private void OnItemAdded (FeedItem item)
         {
             if (item.Enclosure != null) {
-                PodcastTrackInfo track = new PodcastTrackInfo (item);
+                DatabaseTrackInfo track = new DatabaseTrackInfo ();
+                track.ExternalId = item.DbId;
                 track.PrimarySource = source;
+                (track.ExternalObject as PodcastTrackInfo).SyncWithFeedItem ();
                 track.Save (true);
                 RefreshArtworkFor (item.Feed);
             } else {
@@ -297,9 +345,9 @@ namespace Banshee.Podcasting
         
         private void OnItemRemoved (FeedItem item)
         {
-            PodcastTrackInfo track = PodcastTrackInfo.GetByItemId (item.DbId);
+            DatabaseTrackInfo track = GetTrackByItemId (item.DbId);
             if (track != null) {
-                track.Delete ();
+                DatabaseTrackInfo.Provider.Delete (track);
             }
         }
         
@@ -307,13 +355,17 @@ namespace Banshee.Podcasting
         
         private void OnItemChanged (FeedItem item)
         {
-            if (IgnoreItemChanges)
+            if (IgnoreItemChanges) {
                 return;
+            }
 
-            PodcastTrackInfo track = PodcastTrackInfo.GetByItemId (item.DbId);
+            DatabaseTrackInfo track = GetTrackByItemId (item.DbId);
             if (track != null) {
-                track.SyncWithFeedItem ();
-                track.Save (true);
+                PodcastTrackInfo pi = track.ExternalObject as PodcastTrackInfo;
+                if (pi != null) {
+                    pi.SyncWithFeedItem ();
+                    track.Save (true);
+                }
             }
         }
         
@@ -374,9 +426,9 @@ namespace Banshee.Podcasting
         public void AddFeedItem (FeedItem item)
         {
             if (item.Enclosure != null) {
-                PodcastTrackInfo pi = new PodcastTrackInfo (item);
-                pi.PrimarySource = source;
-                pi.Save (true);
+                PodcastTrackInfo pi = new PodcastTrackInfo (new DatabaseTrackInfo (), item);
+                pi.Track.PrimarySource = source;
+                pi.Track.Save (true);
                 source.NotifyUser ();
             } else {
                 item.Delete (false);                      
