@@ -33,7 +33,7 @@ using Gtk;
 
 namespace Hyena.Data.Gui
 {
-    public partial class ListView<T> : Widget
+    public partial class ListView<T> : ListViewBase
     {
         internal struct CachedColumn
         {
@@ -66,6 +66,7 @@ namespace Hyena.Data.Gui
         private int pressed_column_x_drag = -1;
         private int pressed_column_x_start_hadjustment = -1;
         private bool pressed_column_is_dragging = false;
+        private bool pressed_column_drag_started = false;
         
         private Pango.Layout column_layout;
         
@@ -91,14 +92,8 @@ namespace Hyena.Data.Gui
                     continue;
                 }
                 
-                if (column.MinWidth == 0) {
-                    int w;
-                    int h;
-                    column_layout.SetText (column.Title);
-                    column_layout.GetPixelSize (out w, out h);
-                    column.MinWidth = w;
-                }
-                
+                // If we don't already have a MinWidth set, use the width of our Title text
+                column.CalculateWidths (column_layout, HeaderVisible, HeaderHeight);
                 column_cache[i] = new CachedColumn ();
                 column_cache[i].Column = column;
                 column_cache[i].Index = i;
@@ -129,6 +124,7 @@ namespace Hyena.Data.Gui
             }
             
             for (int i = 0; i < column_cache.Length; i++) {
+                // Calculate this column's proportional share of the width, and set positions (X1/X2)
                 column_cache[i].Width = (int)Math.Round (((double)header_width * column_cache[i].Column.Width));
                 column_cache[i].X1 = i == 0 ? 0 : column_cache[i - 1].X2;
                 column_cache[i].X2 = column_cache[i].X1 + column_cache[i].Width;
@@ -164,17 +160,16 @@ namespace Hyena.Data.Gui
                         }
                     }
                 }
-                
-                int min_width = column_cache[i].Column.MinWidth;
-                IHeaderCell header_cell = column_cache[i].Column.HeaderCell as IHeaderCell;
-                if (header_cell != null) {
-                    min_width = header_cell.MinWidth;
-                }
-                min_header_width += column_cache[i].MinWidth = Math.Max (min_width, column_cache[i].Column.MinWidth);
-                column_cache[i].MaxWidth = Math.Max (column_cache[i].Column.MaxWidth, column_cache[i].MinWidth);
+
+                column_cache[i].Column.CalculateWidths (column_layout, HeaderVisible, HeaderHeight);
+                column_cache[i].MaxWidth = column_cache[i].Column.MaxWidth;
+                column_cache[i].MinWidth = column_cache[i].Column.MinWidth;
+                min_header_width += column_cache[i].MinWidth;
             }
-            
-            if (min_header_width >= header_interaction_alloc.Width) {
+
+            if (column_cache.Length == 1) {
+                column_cache[0].Column.Width = 1.0;
+            } else if (min_header_width >= header_interaction_alloc.Width) {
                 header_width = min_header_width;
                 resizable = false;
                 for (int i = 0; i < column_cache.Length; i++) {
@@ -248,25 +243,52 @@ namespace Hyena.Data.Gui
         
         protected virtual void OnColumnRightClicked (Column clickedColumn, int x, int y)
         {
-            Menu menu = new Menu ();
-            
-            if (clickedColumn.Id != null) { // FIXME: Also restrict if the column vis can't be changed
-                menu.Append (new ColumnHideMenuItem (clickedColumn));
-                menu.Append (new SeparatorMenuItem ());
-            }
-            
             Column [] columns = ColumnController.ToArray ();
             Array.Sort (columns, delegate (Column a, Column b) {
                 // Fully qualified type name to avoid Mono 1.2.4 bug
                 return System.String.Compare (a.Title, b.Title);
             });
             
-            foreach (Column column in columns) {
-                if (column.Id == null) {
+            uint items = 0;
+            
+            for (int i = 0; i < columns.Length; i++) {
+                if (columns[i].Id != null) {
+                    items++;
+                }
+            }
+            
+            uint max_items_per_column = 15;
+            if (items >= max_items_per_column * 2) {
+                max_items_per_column = (uint)Math.Ceiling (items / 3.0);
+            } else if (items >= max_items_per_column) {
+                max_items_per_column = (uint)Math.Ceiling (items / 2.0);
+            }
+            
+            uint column_count = (uint)Math.Ceiling (items / (double)max_items_per_column);
+            
+            Menu menu = new Menu ();
+            uint row_offset = 2;
+            
+            if (clickedColumn.Id != null) { // FIXME: Also restrict if the column vis can't be changed
+                menu.Attach (new ColumnHideMenuItem (clickedColumn), 0, column_count, 0, 1);
+                menu.Attach (new SeparatorMenuItem (), 0, column_count, 1, 2);
+            }
+            
+            items = 0;
+            
+            for (uint i = 0, n = (uint)columns.Length, column = 0, row = 0; i < n; i++) {
+                if (columns[i].Id == null) {
                     continue;
                 }
                 
-                menu.Append (new ColumnToggleMenuItem (column));
+                row = items++ % max_items_per_column;
+                
+                menu.Attach (new ColumnToggleMenuItem (columns[i]), 
+                    column, column + 1, row + row_offset, row + 1 + row_offset);
+                
+                if (row == max_items_per_column - 1) {
+                    column++;
+                }
             }
             
             menu.ShowAll ();
@@ -284,10 +306,16 @@ namespace Hyena.Data.Gui
         {
             CachedColumn resizing_column = column_cache[resizing_column_index];
             double resize_delta = x - resizing_column.ResizeX2;
-            
+
+            // Make sure the resize_delta won't make us smaller than the min
             if (resizing_column.Width + resize_delta < resizing_column.MinWidth) {
                 resize_delta = resizing_column.MinWidth - resizing_column.Width;
             }
+
+            // Make sure the resize_delta won't make us bigger than the max
+            if (resizing_column.Width + resize_delta > resizing_column.MaxWidth) {
+                resize_delta = resizing_column.MaxWidth - resizing_column.Width;
+            }
             
             if (resize_delta == 0) {
                 return;
@@ -310,7 +338,8 @@ namespace Hyena.Data.Gui
             if (resize_delta > total_elastic_width) {
                 resize_delta = total_elastic_width;
             }
-            
+
+            // Convert to a proprotional width
             resize_delta = sign * resize_delta / (double)header_width;
             
             for (int i = resizing_column_index + 1; i < column_cache.Length; i++) {
@@ -318,7 +347,7 @@ namespace Hyena.Data.Gui
             }
             
             resizing_column.Column.Width += resize_delta;
-        
+
             RegenerateColumnCache ();
             QueueDraw ();
         }
@@ -329,16 +358,18 @@ namespace Hyena.Data.Gui
                 return null;
             }
             
-            x += (int)hadjustment.Value;
+            x += HadjustmentValue;
             
             for (int i = 0; i < column_cache.Length - 1; i++) {
-                if (x >= column_cache[i].ResizeX1 - 2 && 
-                    x <= column_cache[i].ResizeX2 + 2 &&
+                if (x < column_cache[i].ResizeX1 - 2) {
+                    // No point in checking other columns since their ResizeX1 are even larger
+                    break;
+                } else if (x <= column_cache[i].ResizeX2 + 2 &&
                     column_cache[i].Column.MaxWidth != column_cache[i].Column.MinWidth) {
                     return column_cache[i].Column;
                 }
             }
-            
+
             return null;
         }
         
@@ -348,7 +379,7 @@ namespace Hyena.Data.Gui
                 return null;
             }
             
-            x += (int)hadjustment.Value;
+            x += HadjustmentValue;
             
             foreach (CachedColumn column in column_cache) {
                 if (x >= column.X1 && x <= column.X2) {
@@ -433,12 +464,26 @@ namespace Hyena.Data.Gui
         {
             private Column column;
             private bool ready = false;
+            private Label label;
             
-            public ColumnToggleMenuItem (Column column) : base (column.Title ?? String.Empty)
+            public ColumnToggleMenuItem (Column column) : base ()
             {
                 this.column = column;
                 Active = column.Visible; 
                 ready = true;
+                
+                label = new Label ();
+                label.Xalign = 0.0f;
+                label.Text = column.LongTitle ?? String.Empty;
+                label.Show ();
+                
+                Add (label);
+            }
+                        
+            protected override void OnStyleSet (Style previousStyle)
+            {
+                base.OnStyleSet (previousStyle);
+                label.ModifyFg (StateType.Prelight, Style.Foreground (StateType.Selected));
             }
             
             protected override void OnActivated ()
@@ -453,14 +498,29 @@ namespace Hyena.Data.Gui
             }
         }
         
-        private class ColumnHideMenuItem : MenuItem
+        private class ColumnHideMenuItem : ImageMenuItem
         {
             private Column column;
+            private Label label;
             
-            public ColumnHideMenuItem (Column column) 
-                : base (String.Format (Catalog.GetString ("Hide {0}"), column.Title))
+            public ColumnHideMenuItem (Column column) : base ()
             {
                 this.column = column;
+                this.Image = new Image (Stock.Remove, IconSize.Menu);
+                
+                label = new Label ();
+                label.Xalign = 0.0f;
+                label.Markup = String.Format (Catalog.GetString ("Hide <i>{0}</i>"), 
+                    GLib.Markup.EscapeText (column.LongTitle));
+                label.Show ();
+                
+                Add (label);
+            }
+            
+            protected override void OnStyleSet (Style previousStyle)
+            {
+                base.OnStyleSet (previousStyle);
+                label.ModifyFg (StateType.Prelight, Style.Foreground (StateType.Selected));
             }
             
             protected override void OnActivated ()
